@@ -1,5 +1,4 @@
 import pkg_resources
-import logging
 
 #logging.basicConfig(level=logging.ERROR)
 
@@ -8,8 +7,10 @@ try:
 except:
     version = "unknown"
 
-logging.info("Importing rtools %s." % version)
-logging.info("==========================")
+
+# check that R is available:
+import init
+
 
 # need pylab for that module, which is optional
 try:
