@@ -1,13 +1,14 @@
 from rtools.package import *
+import unittest
 
-
+@unittest.skip
 def test_install_package():
-    url = "http://www.ebi.ac.uk/saezrodriguez/cno/downloads/MEIGOR_0.99.3_svn2719.tar.gz"
-    install_packages(url)
+    install_packages("truncnorm")
 
 
-def _test_biocLite():
-    biocLite("CellNOptR")
+@unittest.skip
+def test_biocLite():
+    biocLite("truncnorm")
 
 def test_Rpackage():
 
